
# Copyright 2022, Frank Sauerburger

"""Movie title suggestion api"""

import json
from flask import Flask, request, abort
import qgram

app = Flask(__name__)

with open("examples/titles.json", encoding="utf-8") as fileobj:
    titles = json.load(fileobj)

movie_ids = {}
movie_titles = {}
index = qgram.QGramIndex()
for tid, (title, year) in titles.items():
    tid = int(tid)
    movie_titles[tid] = (title, year)
    movie_ids[title] = tid
    index.add_term(title)


@app.route("/titles")
def suggest():
    """Serve movie title suggestions"""
    query = request.args.get("q")

    try:
        length = int(request.args.get("l", 12))
        length = min(length, 100)
    except ValueError:
        length = 12

    results = []

    if query:
        results = index.search(query)

    results = results[:length]

    results = [
        (score, title, movie_ids[title])
        for score, title in results
    ]

    return {
        "suggestions": results
    }


@app.route("/titles/<int:mid>")
def byid(mid):
    """Show healthz status"""
    if mid not in movie_titles:
        abort(404)

    title, year = movie_titles[mid]
    return {
        "id": mid,
        "title": title,
        "year": year
    }

@app.route("/titles/healthz")
def healthz():
    """Show healthz status"""
    results = index.search("lord")
    return {"ok": bool(results)}
